import ApiService from '../services/ApiService';
import {
    QUESTIONS_LOADED,
    QUESTIONS_LOAD_ERROR,
    USER_AUTHENTICATED,
    USER_LOGGED_OUT,
    USER_REGISTERED
} from './types';

export const loadQuestions = (userId) => dispatch => {
    const service = new ApiService();
    const scb = (data) => {
        dispatch({
            type: QUESTIONS_LOADED,
            data: data
        });
    }
    const ecb = (error) => {
        dispatch({
            type: QUESTIONS_LOAD_ERROR,
            error: error
        });
    }
    service.getQuestions(userId, scb, ecb);
};

export const loginUser = (username, password, onSuccess, onError) => dispatch => {
    const service = new ApiService();
    const scb = (data) => {
        dispatch({
            type: USER_AUTHENTICATED,
            data: data
        });
        if (onSuccess) onSuccess(data);
    };
    const ecb = (error) => {
        if (onError) onError(error);
    };
    service.login(username, password, scb, ecb);
};

export const registerUser = (username, password, onSuccess, onError) => dispatch => {
    const service = new ApiService();
    const scb = (data) => {
        dispatch({
            type: USER_REGISTERED,
            data: data
        });
        if (onSuccess) onSuccess(data);
    };
    const ecb = (error) => {
        if (onError) onError(error);
    };
    service.register(username, password, scb, ecb);
};

export const getIdentity = (onSuccess, onError) => dispatch => {
    const service = new ApiService();
    const scb = (data) => {
        if (data.id) {
            dispatch({
                type: USER_AUTHENTICATED,
                data: data
            });
        }
        if (onSuccess) onSuccess();
    };
    const ecb = (error) => {
        if (onError) onError(error);
     };

    service.identity(scb, ecb);
};

export const logoutUser = (onSuccess, onError) => dispatch => {
    const service = new ApiService();
    const scb = () => {
        dispatch({
            type: USER_LOGGED_OUT,
            data: {}
        });
        if (onSuccess) onSuccess();
    };
    const ecb = (error) => {
        if (onError) onError(error);
     };

    service.logoutUser(scb, ecb);
};
