import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { logoutUser } from '../../actions/appActions';
import { Link } from 'react-router-dom';
import { withRouter, Redirect } from "react-router";
import { Layout, Menu, Typography } from 'antd';
import 'antd/dist/antd.css';
import {
  UserOutlined
} from '@ant-design/icons';

const { Header } = Layout;
const { SubMenu } = Menu;

const styles = {
  logo: {
    float: 'left',
    color: 'white',
    fontSize: '1.4em',
    marginRight: 30,
    fontFamily: 'Helvetica'
  },

  logoImage: {
    float: 'left',
    color: 'white',
    marginRight: 30,
    marginTop: 7,
    height: 50,
    width: 50
  }
};

class AppHeader extends Component {

  constructor(props) {
    super(props);
    this.state = {
      logoutSuccess: false,
      redirectToStart: false,
      redirectToAdmin: false
    }
  }

  handleClick = e => {
    switch (e.key) {
      case 'logout':
        this.props.logoutUser(() => {
          this.setState({
            logoutSuccess: true
          });
        }, (error) => {
          console.log('error logging out: ' + error);
        });
        break;
      case 'start':
        this.setState({
          redirectToStart: true
        });
        break;
      case 'admin':
        this.setState({
          redirectToAdmin: true
        });
      default:
        break;
    }
  };

  render() {

    let userInfo = (
      <Link to="/login">
        <Typography>login</Typography>
      </Link>
    );

    const redirectAfterLogout = this.state.logoutSuccess ? <Redirect to='/login' /> : <div></div>
    const redirectToStart = this.state.redirectToStart ? <Redirect to='/start' /> : <div></div>
    const redirectToAdmin = this.state.redirectToAdmin ? <Redirect to='/admin' /> : <div></div>

    let adminSubmenu;
    if (this.props.user && this.props.user.role === 'admin') {
      adminSubmenu = <Menu.Item key='admin'>admin</Menu.Item>
    }

    if (this.props.user) {
      userInfo = (
        <Menu theme='dark' onClick={this.handleClick} mode="horizontal">
          <SubMenu
            key="user"
            title={
              <span>
                <UserOutlined />
                <span>{this.props.user.username}</span>
              </span>
            }>
            <Menu.Item key="start">start</Menu.Item>
            {adminSubmenu}
            <Menu.Item key="logout">logout</Menu.Item>
          </SubMenu>
        </Menu>
      )
    };

    return (
      <Header style={{ position: 'fixed', zIndex: 1, width: '100%', background: '#3399cc' }}>
        {redirectAfterLogout}
        {redirectToStart}
        {redirectToAdmin}
        <div style={styles.logo}>
          <img style={styles.logoImage} src='images/logo.png' alt='' />
          <Link style={styles.logo} to="/">Die Gesellschaft der Gegenwart</Link>
        </div>
        <div style={{ float: 'right' }}>
          {userInfo}
        </div>
      </Header>
    )
  }
};

AppHeader.propTypes = {
  logoutUser: PropTypes.func.isRequired,
  user: PropTypes.object
};

const mapStateToProps = state => ({
  user: state.appData.user
});

export default withRouter(connect(mapStateToProps, { logoutUser })(AppHeader));
