import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { loginUser } from '../../actions/appActions';
import { Form, Input, Button, Typography } from 'antd';
import { Redirect } from 'react-router-dom';

const layout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 16,
  },
};
const tailLayout = {
  wrapperCol: {
    offset: 8,
    span: 16,
  },
};

class Login extends Component {

  constructor(props) {
    super(props);
    this.state = {
      loginErrorMessage: undefined,
      loginSuccess: false
    }
  }

  onFinish = values => {
    console.log('on finish');
    this.props.loginUser(values.username, values.password, (user) => {
      this.setState({
        loginErrorMessage: undefined,
        loginSuccess: true
      });
    }, (error) => {
      this.setState({
        loginErrorMessage: error.message
      });
    });
  };

  onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
  };



  render() {

    let errorMessageStyle = { display: 'none' };
    if (this.state.loginErrorMessage) {
      errorMessageStyle = {};
    }

    const redirectAfterLogin = this.state.loginSuccess ? <Redirect to='/' /> : <div></div>


    return (
      <div>
        {redirectAfterLogin}
        <h2 style={{ textAlign: 'center' }}>Login</h2>
        <Form
          {...layout}
          name="basic"
          initialValues={{
            remember: true,
          }}
          onFinish={this.onFinish}
          onFinishFailed={this.onFinishFailed}
        >
          <Form.Item
            label="Username"
            name="username"
            rules={[
              {
                required: true,
                message: 'Please input your username!',
              },
            ]}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label="Password"
            name="password"
            rules={[
              {
                required: true,
                message: 'Please input your password!',
              },
            ]}
          >
            <Input.Password />
          </Form.Item>

          <Form.Item
            style={errorMessageStyle}
            label=" "
            colon={false}
            name="error message">
            <Typography.Text className="ant-form-text" type="danger">
              {this.state.loginErrorMessage}
            </Typography.Text>
          </Form.Item>

          <Form.Item {...tailLayout}>
            <Button type="primary" htmlType="submit">
              Submit
        </Button>
          </Form.Item>
        </Form>
      </div>
    )
  };

};

Login.propTypes = {
  loginUser: PropTypes.func.isRequired
};

const mapStateToProps = state => ({});

export default connect(mapStateToProps, { loginUser })(Login);
