import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { registerUser } from '../../actions/appActions';
import { Form, Input, Button, Typography } from 'antd';

const layout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 16,
  },
};
const tailLayout = {
  wrapperCol: {
    offset: 8,
    span: 16,
  },
};

class Register extends Component {

  constructor(props) {
    super(props);
    this.state = {
      registerErrorMessage: undefined
    }
  }

  onFinish = values => {
    this.props.registerUser(values.username, values.password, (user) => {
      this.setState({
        registerErrorMessage: undefined
      });
    }, (error) => {
      this.setState({
        registerErrorMessage: error.message
      });
    });
  };

  onFinishFailed = errorInfo => { };

  render() {

    let errorMessageStyle = { display: 'none' };
    if (this.state.registerErrorMessage) {
      errorMessageStyle = {};
    }

    return (
      <div>
        <h2 style={{ textAlign: 'center' }}>Register</h2>
        <Form
          {...layout}
          name="basic"
          initialValues={{
            remember: true,
          }}
          onFinish={this.onFinish}
          onFinishFailed={this.onFinishFailed}
        >
          <Form.Item
            label="Username"
            name="username"
            rules={[
              {
                required: true,
                message: 'Please input your username!',
              },
            ]}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label="Password"
            name="password"
            rules={[
              {
                required: true,
                message: 'Please input your password!',
              },
            ]}
          >
            <Input.Password />
          </Form.Item>

          <Form.Item
            style={errorMessageStyle}
            label=" "
            colon={false}
            name="error message">
            <Typography.Text className="ant-form-text" type="danger">
              {this.state.registerErrorMessage}
            </Typography.Text>
          </Form.Item>

          <Form.Item {...tailLayout}>
            <Button type="primary" htmlType="submit">
              Submit
        </Button>
          </Form.Item>
        </Form>
      </div>
    )
  };

};

Register.propTypes = {
  registerUser: PropTypes.func.isRequired
};

const mapStateToProps = state => ({});

export default connect(mapStateToProps, { registerUser })(Register);
