import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Redirect } from 'react-router-dom';
import { createPublicState } from '../../../actions/gameActions';
import { Form, Input, Button, Typography, InputNumber } from 'antd';

const layout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 16,
  },
};
const tailLayout = {
  wrapperCol: {
    offset: 8,
    span: 16,
  },
};

class CreatePublicState extends Component {

  constructor(props) {
    super(props);
    this.state = {
      createErrorMessage: undefined,
      stateCreated: undefined
    };
  };

  onFinish = values => {
    
    let scb = (state) => {
      console.log('state')
      this.setState({
        createErrorMessage: undefined,
        stateCreated: state
      });
    };

    let ecb = (error) => {
      this.setState({
        createErrorMessage: error.message
      });
    };

    let requestData = {
      name: values.name,
      title: values.title
    };

    this.props.createPublicState(requestData, scb, ecb);
  };

  onFinishFailed = errorInfo => { };

  render() {

    let errorMessageStyle = { display: 'none' };
    if (this.state.createErrorMessage) {
      errorMessageStyle = {};
    }

    if (this.state.stateCreated) {
      console.log('redirect to state/' + this.state.stateCreated.name);
      return (
        <Redirect to={'/state/' + this.state.stateCreated.name} />
      )
    } else {
      return (
        <div>
          <h2 style={{ textAlign: 'center' }}>Create Public State</h2>
          <Form
            {...layout}
            name="basic"
            initialValues={{
              remember: true,
            }}
            onFinish={this.onFinish}
            onFinishFailed={this.onFinishFailed}
          >
            <Form.Item
              label="Name"
              name="name"
              rules={[
                {
                  required: true,
                  message: 'Please input the name of the Public State!',
                },
              ]}
            >
              <Input />
            </Form.Item>

            <Form.Item
              label="Title"
              name="title"
              rules={[
                {
                  required: false,
                  message: 'Please input the title of the public state',
                },
              ]}
            >
              <Input />
            </Form.Item>

            <Form.Item
              label="Minimum number of Citizen per private state"
              name="privateStateMinCitizen"
              rules={[
                {
                  required: false,
                  message: 'Please input the minimum number of citizen that can constitute a private state',
                },
              ]}
            >
              <InputNumber defaultValue={3} min={2} />
            </Form.Item>

            <Form.Item
              style={errorMessageStyle}
              label=" "
              colon={false}
              name="error message">
              <Typography.Text className="ant-form-text" type="danger">
                {this.state.createErrorMessage}
              </Typography.Text>
            </Form.Item>

            <Form.Item {...tailLayout}>
              <Button type="primary" htmlType="submit">
                Submit
        </Button>
            </Form.Item>
          </Form>
        </div >
      )
    }
  }
};

CreatePublicState.propTypes = {
  createPublicState: PropTypes.func.isRequired
};

const mapStateToProps = state => ({});

export default connect(mapStateToProps, { createPublicState })(CreatePublicState);
