import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { getIdentity } from '../actions/appActions';
import {
  BrowserRouter as Router,
  Redirect,
  Route,
  Switch
} from 'react-router-dom';
import { Layout } from 'antd';
import {
  AdminDashboardPage,
  DashboardPage,
  LoginPage,
  PublicStateOverviewPage,
  RegisterPage,
  SplashScreenPage,
  WelcomePage
} from '../pages';
import { AppHeader } from '../components';
import 'antd/dist/antd.css';

const { Content } = Layout;

export const AuthenticatedRoute = ({ children, ...rest }) => {
  return (
    <Route
      {...rest}
      render={({ location }) =>
        rest.user ? (
          children
        ) : (
            <Redirect
              to={{
                pathname: "/login",
                state: { from: location }
              }}
            />
          )
      }
    />
  );
};

export const AdminRoute = ({ children, ...rest }) => {
  return (
    <Route
      {...rest}
      render={({ location }) =>
        (rest.user && rest.user.role === 'admin') ? (
          children
        ) : (
            <Redirect
              to={{
                pathname: "/admin/autherror",
                state: { from: location }
              }}
            />
          )
      }
    />
  );
};


class AppRouter extends Component {

  constructor(props) {
    super(props);
    this.state = {
      identityChecked: false
    }
  }

  componentDidMount = () => {
    const scb = () => {
      this.setState({
        identityChecked: true
      })
    };
    this.props.getIdentity(scb);
  };

  render() {

    if (this.state.identityChecked) {
      return (
        <Router>
          <Layout style={{ height: "100%" }}>
            <AppHeader />
            <Content style={{ padding: '0 50px', marginTop: 64 }}>
              <div style={{ background: '#fff', padding: 24 }}>
                <Switch>
                  <Route exact path='/'><WelcomePage /></Route>
                  <Route exact path='/login'><LoginPage /></Route>
                  <Route exact path='/register'><RegisterPage /></Route>
                  <Route exact path='/admin/autherror'><div>not an admin</div></Route>
                  <AuthenticatedRoute exact path='/start' user={this.props.user}><DashboardPage /></AuthenticatedRoute>
                  <AuthenticatedRoute exact path='/state/:name' user={this.props.user}><PublicStateOverviewPage /></AuthenticatedRoute>
                  <AdminRoute exact path='/admin' user={this.props.user}><AdminDashboardPage /></AdminRoute>
                </Switch>
              </div>
            </Content>
          </Layout>
        </Router>
      )
    } else {
      return (
        <SplashScreenPage />
      )
    }
  };
};

AppRouter.propTypes = {
  getIdentity: PropTypes.func.isRequired,
  user: PropTypes.object,
};

const mapStateToProps = state => ({
  user: state.appData.user
});

export default connect(mapStateToProps, { getIdentity })(AppRouter);
